@@ -14,6 +14,8 @@ Options:
  -l --lectures-repo=<lecture>       The git repository to fetch the builtin lessons content. The default branch will be used.
  --lectures-directory=<lecture>     A path to the directory containing the builtin lessons content. Cannot be used with `--lectures-repo`.
  -e --example=<examples>...         A list of repositories to fetch worked examples from. The default branch will be used.
+ --static-url=<url>                 A url to a public server that holds the static lectures content, so it does not need to be included to reduce the image size.
+ --motd-file=<file>                 A file that contains the content of the Message Of The Day, to be printed when the container starts and when a user gets a shell in the container.
 
 General git options:
   --key-file=<key_file>             The path to the ssh private key that should be used.
@@ -302,12 +304,13 @@ def cleanup_build(dir):
 
 
 def build_multi_arch(
-    client, dir, tag="sci-oer:custom", base=None, push=False, **kwargs
+    client, dir, tag="sci-oer:custom", base=None, push=False, static_url=None, **kwargs
 ):
 
     args = {
         "BASE_IMAGE": base,
         "BUILD_DATE": datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ"),
+        "REMOTE_STATIC_SERVER_URL": static_url or "",
     }
 
     _LOGGER.info(f"Building custom image with name `{tag}`...")
@@ -327,11 +330,14 @@ def build_multi_arch(
     _LOGGER.info("Done building custom image.")
 
 
-def build_single_arch(client, dir, tag="sci-oer:custom", base=None, **kwargs):
+def build_single_arch(
+    client, dir, tag="sci-oer:custom", base=None, static_url=None, **kwargs
+):
 
     args = {
         "BASE_IMAGE": base,
         "BUILD_DATE": datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ"),
+        "REMOTE_STATIC_SERVER_URL": static_url or "",
     }
 
     _LOGGER.info(f"Building custom image with name `{tag}`...")
@@ -641,9 +647,9 @@ def wait_for_wiki_to_be_ready(host, port=3000, **kwargs):
         _LOGGER.info("wiki is ready")
 
 
-def get_real_key_path(container, keyName):
+def get_real_file_path(container, fileName):
 
-    mounts = [m for m in container.attrs["Mounts"] if m["Destination"] == keyName]
+    mounts = [m for m in container.attrs["Mounts"] if m["Destination"] == fileName]
 
     if len(mounts) != 0:
         return mounts[0]["Source"]
@@ -667,6 +673,10 @@ def run(opts, **kwargs):
         )
         sys.exit("Incompatible arguments")
 
+    motdFile = None
+    if opts["motd_file"]:
+        motdFile = os.path.realpath(os.path.expanduser(opts["motd_file"]))
+
     sshKeyFile = load_ssh_key(os.path.expanduser(opts["key_file"] or ""))
     if sshKeyFile != "":
         sshKeyFile = os.path.realpath(sshKeyFile)
@@ -694,7 +704,7 @@ def run(opts, **kwargs):
         this = get_current_container(client)
         network.connect(this)
 
-        realKey = get_real_key_path(this, opts["key_file"])
+        realKey = get_real_file_path(this, opts["key_file"])
 
     volume = create_volume(client, "course")
     container = start_container(
@@ -766,6 +776,14 @@ def run(opts, **kwargs):
     else:
         _LOGGER.info("no example repos were specified, skipping...")
 
+    if motdFile:
+        _LOGGER.info("Copying custom motd.txt file...")
+        shutil.copy2(motdFile, os.path.join(dir.name, "motd.txt"))
+    else:
+        _LOGGER.info("Copying default motd.txt file...")
+        with pkg_resources.path("builder.data", "motd.txt") as template:
+            shutil.copy2(template, os.path.join(dir.name, "motd.txt"))
+
     if opts["wiki_git_repo"] is not None:
         wikiRepo = Repository(
             opts["wiki_git_repo"],
@@ -797,11 +815,22 @@ def run(opts, **kwargs):
     if opts["multi_arch"]:
         _LOGGER.info("Starting multi platform build")
         build_multi_arch(
-            client, dir.name, tag=opts["tag"], base=opts["base"], push=opts["push"]
+            client,
+            dir.name,
+            tag=opts["tag"],
+            base=opts["base"],
+            push=opts["push"],
+            static_url=opts["static_url"],
         )
     else:
         _LOGGER.info("Starting single platform build")
-        build_single_arch(client, dir.name, tag=opts["tag"], base=opts["base"])
+        build_single_arch(
+            client,
+            dir.name,
+            tag=opts["tag"],
+            base=opts["base"],
+            static_url=opts["static_url"],
+        )
 
     cleanup_build(dir)
 
